@@ -22,7 +22,8 @@ def _resource_type(unique_id: str) -> str:
 
 
 def _get_input_name(node_info: Mapping[str, Any]) -> str:
-    return node_info["unique_id"].replace(".", "_")
+    # * can be present when sources are sharded tables
+    return node_info["unique_id"].replace(".", "_").replace("*", "_star")
 
 
 def _get_output_name(node_info: Mapping[str, Any]) -> str:
@@ -143,7 +144,14 @@ def result_to_events(
             if node_info is None:
                 continue
             upstream_asset_key = node_info_to_asset_key(node_info)
-            yield AssetObservation(asset_key=upstream_asset_key, metadata=metadata)
+            yield AssetObservation(
+                asset_key=upstream_asset_key,
+                metadata={
+                    "Test ID": result["unique_id"],
+                    "Test Status": status,
+                    "Test Message": result.get("message") or "",
+                },
+            )
 
 
 def generate_events(
